# p3y3

---

#### *3y3 encoding in Python*

> Based on https://synthetic.garden/3y3.htm


It's a [Hypnospace Outlaw](https://store.steampowered.com/app/844590/Hypnospace_Outlaw/) reference!
The main function is called [`second_sightify`](https://hypnospace.wiki.gg/wiki/Second_Sight).

---

## Usage

```python
from p3y3 import second_sightify
print(repr(second_sightify("Hello, world!")))
# Output:
# '\U000e0048\U000e0065\U000e006c\U000e006c\U000e006f\U000e002c\U000e0020\U000e0077\U000e006f\U000e0072\U000e006c\U000e0064\U000e0021'
# (invisible text ^^)
```
